*************
probnum.utils
*************

Utility Functions.

.. automodapi:: probnum.utils
    :no-inheritance-diagram:
    :no-heading:
    :headings: "="
    :no-main-docstr:

probnum.utils.linalg
====================

Utility functions involving (numerical) linear algebra.

.. automodapi:: probnum.utils.linalg
    :no-heading:
    :no-main-docstr:
